@@ -23,6 +23,7 @@
 //===----------------------------------------------------------------------===//
 
 #include <utility>
+#include <vector>
 #include <range/v3/core.hpp>
 #include <range/v3/algorithm/replace_if.hpp>
 #include "../simple_test.hpp"
@@ -34,7 +35,7 @@ void test_iter()
 {
     int ia[] = {0, 1, 2, 3, 4};
     const unsigned sa = sizeof(ia)/sizeof(ia[0]);
-    Iter i = ranges::replace_if(Iter(ia), Sent(ia+sa), [](int i){return i==2;}, 5);
+    Iter i = ranges::replace_if(Iter(ia), Sent(ia+sa), [](int j){return j==2;}, 5);
     CHECK(ia[0] == 0);
     CHECK(ia[1] == 1);
     CHECK(ia[2] == 5);
@@ -48,8 +49,8 @@ void test_rng()
 {
     int ia[] = {0, 1, 2, 3, 4};
     const unsigned sa = sizeof(ia)/sizeof(ia[0]);
-    auto rng = ranges::make_iterator_range(Iter(ia), Sent(ia+sa));
-    Iter i = ranges::replace_if(rng, [](int i){return i==2;}, 5);
+    auto rng = ranges::make_subrange(Iter(ia), Sent(ia+sa));
+    Iter i = ranges::replace_if(rng, [](int j){return j==2;}, 5);
     CHECK(ia[0] == 0);
     CHECK(ia[1] == 1);
     CHECK(ia[2] == 5);
@@ -60,29 +61,29 @@ void test_rng()
 
 int main()
 {
-    test_iter<forward_iterator<int*> >();
-    test_iter<bidirectional_iterator<int*> >();
-    test_iter<random_access_iterator<int*> >();
+    test_iter<ForwardIterator<int*> >();
+    test_iter<BidirectionalIterator<int*> >();
+    test_iter<RandomAccessIterator<int*> >();
     test_iter<int*>();
 
-    test_iter<forward_iterator<int*>, sentinel<int*> >();
-    test_iter<bidirectional_iterator<int*>, sentinel<int*> >();
-    test_iter<random_access_iterator<int*>, sentinel<int*> >();
+    test_iter<ForwardIterator<int*>, Sentinel<int*> >();
+    test_iter<BidirectionalIterator<int*>, Sentinel<int*> >();
+    test_iter<RandomAccessIterator<int*>, Sentinel<int*> >();
 
-    test_rng<forward_iterator<int*> >();
-    test_rng<bidirectional_iterator<int*> >();
-    test_rng<random_access_iterator<int*> >();
+    test_rng<ForwardIterator<int*> >();
+    test_rng<BidirectionalIterator<int*> >();
+    test_rng<RandomAccessIterator<int*> >();
     test_rng<int*>();
 
-    test_rng<forward_iterator<int*>, sentinel<int*> >();
-    test_rng<bidirectional_iterator<int*>, sentinel<int*> >();
-    test_rng<random_access_iterator<int*>, sentinel<int*> >();
+    test_rng<ForwardIterator<int*>, Sentinel<int*> >();
+    test_rng<BidirectionalIterator<int*>, Sentinel<int*> >();
+    test_rng<RandomAccessIterator<int*>, Sentinel<int*> >();
 
     // test projection
     {
         using P = std::pair<int,std::string>;
         P ia[] = {{0,"0"}, {1,"1"}, {2,"2"}, {3,"3"}, {4,"4"}};
-        P *i = ranges::replace_if(ia, [](int i){return i==2;}, std::make_pair(42,"42"),
+        P *i = ranges::replace_if(ia, [](int j){return j==2;}, std::make_pair(42,"42"),
             &std::pair<int,std::string>::first);
         CHECK(ia[0] == P{0,"0"});
         CHECK(ia[1] == P{1,"1"});
@@ -92,18 +93,33 @@ int main()
         CHECK(i == ranges::end(ia));
     }
 
-    // test rvalue range
+    // test rvalue ranges
     {
         using P = std::pair<int,std::string>;
         P ia[] = {{0,"0"}, {1,"1"}, {2,"2"}, {3,"3"}, {4,"4"}};
-        auto i = ranges::replace_if(ranges::view::all(ia), [](int i){return i==2;}, std::make_pair(42,"42"),
+        auto i = ranges::replace_if(std::move(ia), [](int j){return j==2;}, std::make_pair(42,"42"),
             &std::pair<int,std::string>::first);
+#ifndef RANGES_WORKAROUND_MSVC_573728
+        CHECK(::is_dangling(i));
+#endif // RANGES_WORKAROUND_MSVC_573728
+        CHECK(ia[0] == P{0,"0"});
+        CHECK(ia[1] == P{1,"1"});
+        CHECK(ia[2] == P{42,"42"});
+        CHECK(ia[3] == P{3,"3"});
+        CHECK(ia[4] == P{4,"4"});
+    }
+
+    {
+        using P = std::pair<int,std::string>;
+        std::vector<P> ia{{0,"0"}, {1,"1"}, {2,"2"}, {3,"3"}, {4,"4"}};
+        auto i = ranges::replace_if(std::move(ia), [](int j){return j==2;}, std::make_pair(42,"42"),
+            &std::pair<int,std::string>::first);
+        CHECK(::is_dangling(i));
         CHECK(ia[0] == P{0,"0"});
         CHECK(ia[1] == P{1,"1"});
         CHECK(ia[2] == P{42,"42"});
         CHECK(ia[3] == P{3,"3"});
         CHECK(ia[4] == P{4,"4"});
-        CHECK(i.get_unsafe() == ranges::end(ia));
     }
 
     return ::test_result();
